==> mediawiki-1.12.1.tar.gz: mediawiki-1.12.1/languages/messages/MessagesYo.php <==
<?php
/** Yoruba (Yorùbá)
 *
 * @ingroup Language
 * @file
 *
 * @author Demmy
 */

$messages = array(
# User preference toggles
'tog-underline'            => 'Underline links:',
'tog-justify'              => "S'àlàyé gbólóhùn ọ̀rọ̀",
'tog-hideminor'            => "Bo àtúnse kékékèé mọ́'lẹ̀ nínú àtúnse tuntun",
'tog-rememberpassword'     => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi",
'tog-watchcreations'       => "S'àfikún ojúewé tí mo dá mọ́ ìmójútó mi",
'tog-watchdefault'         => "S'àfikún ojúewé tí mo s'àtúnse mọ́ ìmójútó mi",
'tog-watchmoves'           => "S'àfikún ojúewé tí mo kó kúrò mọ́ ìmójútó mi",
'tog-watchdeletion'        => "S'àfikún ojúewé tí mo parẹ́ mọ́ ìmójútó mi",
'tog-minordefault'         => "Se àmì sí gbogbo àtúnse gẹ́gẹ́ bi kékeré lát'ìbẹ̀rẹ̀.",
'tog-previewontop'         => "Se àyẹ̀wò kí ẹ tó s'àtúnṣe",
'tog-previewonfirst'       => "S'àfihàn àgbéwò fún àtúnse àkọ́kọ́",
'tog-nocache'              => "D'ènà fífi ojúewé pamọ́",
'tog-enotifwatchlistpages' => 'Fi e-mail ránsẹ́ sími tí ojúewé tí mò ún mójútó bá yípadà',
'tog-enotifusertalkpages'  => 'Fi e-mail ránsẹ́ sími tí ojúewé ẹnitínse mi bá yípadà',
'tog-enotifminoredits'     => 'Fi e-mail ránsẹ́ sími bákannà fún àtúnse kékékèé sí ojúewé',
'tog-shownumberswatching'  => "S'àfihàn iye àwọn ẹnitínse tí wọn ún mójútó",

'underline-always' => 'Nígbà gbogbo',

# Dates
'sunday'    => 'Ọjọ́àìkú',
'monday'    => 'Ọjọ́ajé',
'tuesday'   => 'Ọjọ́ìsẹ́gun',
'wednesday' => 'Ọjọ́rú',
'thursday'  => 'Ọjọ́bọ̀',
'friday'    => 'Ọjọ́ẹtì',
'saturday'  => 'Ọjọ́àbámẹ́ta',

'about'          => 'Nípa',
'cancel'         => "Fa'gilé",
'qbfind'         => 'Wá rí',
'qbedit'         => 'Àtúnṣe',
'qbpageoptions'  => 'Ojúewé yi',
'qbmyoptions'    => 'Àwọn ojúewé mi',
'qbspecialpages' => 'Àwọn ojúewé pàtàkì',
'moredotdotdot'  => 'Ẹ̀kúnrẹ́rẹ́...',
'mypage'         => 'Ojúewé mi',
'mytalk'         => 'Ọ̀rọ̀ mi',
'navigation'     => 'Atọ́ka',
'and'            => 'àti',

'errorpagetitle'   => 'Àsìse',
'tagline'          => "Lát'ọwọ́ {{SITENAME}}",
'help'             => 'Ìrànlọ́wọ́',
'search'           => 'Ṣe àwáàrí',
'searchbutton'     => 'Ṣe àwáàrí',
'go'               => 'Ó yá',
'searcharticle'    => 'Ó yá',
'edit'             => 'Àtúnṣe',
'editthispage'     => "S'àtúnṣe ojúewé yi",
'delete'           => 'Paarẹ́',
'deletethispage'   => 'Pa ojúewé yi rẹ́',
'protect'          => 'Dábòbò',
'protectthispage'  => 'Dá àbò bo ojúewé yìí',
'newpage'          => 'Ojúewé tuntun',
'talkpage'         => 'Kábárawasọ̀rọ̀ nípa ojúewé yi',
'talkpagelinktext' => 'Kábárawasọ̀rọ̀',
'specialpage'      => 'Ojúewé Pàtàkì',
'talk'             => 'Ìfọ̀rọ̀wérọ̀',
'toolbox'          => 'Àpótí irinṣẹ',
'otherlanguages'   => 'Àwọn èdè míràn',
'lastmodifiedat'   => 'Ọjọ́ tí a ṣe àtunṣe ojúewé yi gbẹ̀yìn ni $2, $1.', # $1 date, $2 time
'viewcount'        => 'A ti wo ojúewé yi ni {{PLURAL:$1|ẹ̀kan péré|iye ìgbà $1}}.',
'jumptonavigation' => 'atọ́ka',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'         => 'Nípa {{SITENAME}}',
'aboutpage'         => 'Project:Nípa',
'copyright'         => 'Gbogbo ohun inú ibí yi wà lábẹ́  $1.',
'copyrightpagename' => '{{SITENAME}} ẹ̀tọ́àwòkọ',
'copyrightpage'     => '{{ns:project}}:Ẹ̀tọ́àwòko',
'currentevents'     => 'Ìròhìn nísinsìnyí',
'currentevents-url' => 'Project:Ìròhìn nísinsìnyí',
'edithelp'          => "Ìrànlọ́wọ́ láti s'àtúnṣe",
'edithelppage'      => 'Help:Àtúnṣe',
'mainpage'          => 'Ojúewé Àkọ́kọ́',
'portal'            => 'Èbúté àwùjọ',
'portal-url'        => 'Project:Èbúté Àwùjọ',
'sitesupport'       => 'Se ẹ̀bùn owó',

'badaccess-group0' => "A kò gbàyín l'áyè l'áti ṣe ohun tí ẹ bèrè fún.",

'youhavenewmessages'      => 'Ẹ ní $1 ($2).',
'newmessageslink'         => 'ìfọ̀rọ̀ránsẹ́ tuntun',
'youhavenewmessagesmulti' => 'Ẹ ní ìfọ̀rọ̀ránsẹ́ tuntun ni $1',
'editsection'             => "s'àtúnṣe",
'editold'                 => "s'àtúnṣe",
'showtoc'                 => 'fihàn',
'hidetoc'                 => 'bòmọ́lẹ̀',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Àyọkà',
'nstab-user'      => 'Ojúewé oníṣe',
'nstab-media'     => 'Ojúewé amóhùnmáwòrán',
'nstab-special'   => 'Pàtàkì',
'nstab-mediawiki' => 'Ìfọ̀rọ̀ránsẹ',
'nstab-category'  => 'Ẹ̀ka',

# General errors
'viewsource'        => 'Àfihàn ọ̀rọ̀àmì',
'protectedpagetext' => 'A ti se àtìpa ojúewé yi. Ẹ kò le se àtúnṣe.',
'viewsourcetext'    => 'Ẹ lè wo ati ẹ lè se àwòkọ ọ̀rọ̀àmì ojúewé yi:',
'titleprotected'    => "This title has been protected from creation by [[User:$1|$1]]. The reason given is ''$2''.",

# Login and logout pages
'logouttitle'         => 'Ibọsóde oníṣe',
'welcomecreation'     => "== Ẹ kú àbọ̀, $1! ==

A ti fi orúkọ yín s'ílẹ̀. Ẹ mọ́ gbàgbé l'áti s'àtúnṣe àwọn ìfẹ́ràn {{SITENAME}} yín.",
'loginpagetitle'      => 'Ìwọlé oníṣe',
'yourname'            => 'Orúkọ oníṣe (username):',
'yourpassword'        => 'Ọ̀rọ̀ìpamọ́:',
'yourpasswordagain'   => 'Tẹkíkọ ọ̀rọ̀ìpamọ́ lẹ́ẹ̀kansí:',
'remembermypassword'  => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi (cookies)",
'loginproblem'        => '<b>Ẹ ní ìṣòro láti wọlé.</b><br />Ẹ gbìyànjú lẹ́kan sí!',
'login'               => 'Ìwọlé',
'userlogin'           => 'Ìwọlé / ìforúkọ sílẹ̀',
'logout'              => 'Ìbọ́sóde',
'userlogout'          => 'Ìbọ́sóde',
'notloggedin'         => "Ẹ kò tí w'ọlé",
'nologinlink'         => 'Ẹ fi orúkọ sílẹ̀',
'createaccount'       => 'Ẹ fi orúkọ sílẹ̀',
'gotaccountlink'      => "Ẹ w'ọlé",
'createaccountmail'   => 'pẹ̀lú e-mail',
'badretype'           => 'Àwọn ọ̀rọ̀ìpamọ́ tí ẹ kọ kò jọ ra wọn.',
'username'            => 'Orúkọ oníṣe:',
'uid'                 => 'Nọmba ìdámọ̀ fún ẹnitínṣe:',
'yourlanguage'        => 'Èdè:',
'accountcreated'      => 'Ẹ ti fi orúkọ sílẹ̀',
'accountcreatedtext'  => 'A ti fi orúkọ ẹnitínṣe sílẹ̀ fún $1',
'createaccount-title' => 'Ìforúkọ sílẹ̀ fún {{SITENAME}}',
'loginlanguagelabel'  => 'Èdè: $1',

# Edit pages
'minoredit'        => 'Àtúnṣe kékeré nìyí',
'watchthis'        => "M'ójútó ojúewé yìí",
'savearticle'      => 'Ẹ fi pamọ́',
'preview'          => 'Àyẹ̀wò',
'showpreview'      => 'Àyẹ̀wò',
'showdiff'         => 'Àfihàn àwọn àyípadà',
'anoneditwarning'  => "'''Ìkìlọ̀:''' Ẹ ò tíì wọlé.
Á ṣe àkọsílẹ̀ ojúọ̀nà IP yín ninu ìwé àtúnṣe ojúewé yìí.",
'loginreqtitle'    => "Ẹ gbọ́dọ̀ kọ́kọ́ w'ọlé ná",
'newarticle'       => '(Tuntun)',
'newarticletext'   => "Ẹ ti tẹ̀lé ìjápọ̀ mọ́ ojúewé tí kò sí.
Láti dá ojúewé yí ẹ bẹ̀rẹ̀ síní tẹ́kọ sí inú àpótí ìsàlẹ̀ yí (ẹ wo [[{{MediaWiki:Helppage}}|ojúewé ìrànlọ́wọ́ ]] fun ẹ̀kúnrẹ́rẹ́ ).
T'óbá sepé àsìse ló gbé yin dé bi, ẹ kọn bọ́tìnì ìpadàsẹ́yìn.",
'note'             => '<strong>Àkíyèsí:</strong>',
'copyrightwarning' => 'Ẹ jọ̀wọ́ ẹ kíyèsi wípé gbogbo àwọn àfikún sí {{SITENAME}} jẹ́ bẹ̀ lábẹ́  $2 (Ẹ wo $1 fún ẹkunrẹrẹ ).
If you do not want your writing to be edited mercilessly and redistributed at will, then do not submit it here.<br />
You are also promising us that you wrote this yourself, or copied it from a public domain or similar free resource.
<strong>Ẹ mọ́ fi iṣẹ́ ẹlòmíràn sílẹ̀ láì gbàṣẹ!</strong>',

# Revision deletion
'rev-delundel' => 'fihàn/fipamọ́',

# Search results
'searchresults' => 'Àwọn èsì àwáàrí',
'powersearch'   => 'Ṣe àwáàrí',

# Preferences page
'preferences'      => 'Àwọn ìfẹ́ràn',
'mypreferences'    => 'Àwọn ìfẹ́ràn mi',
'prefs-edits'      => 'Iye àwọn àtúnṣe:',
'prefsnologintext' => 'Ẹ gbọ́dọ̀ [[Special:UserLogin|wọlé]] láti to àwọn ìfẹ́ràn oníṣe.',
'prefs-personal'   => 'Ọ̀rọ̀ nípa oníṣe',
'savedprefs'       => 'Àwọn ìfẹ́ràn yín ti wà nípamọ́.',

# Recent changes
'recentchanges' => 'Àwọn àtúnṣe tuntun',

# Image list
'filehist-user'  => 'Oníṣe',
'imagelist_name' => 'Orúkọ',
'imagelist_user' => 'Oníṣe',

# File deletion
'filedelete'        => 'Paarẹ́ $1',
'filedelete-submit' => 'Paarẹ́',

# Miscellaneous special pages
'allpages'          => 'Gbogbo ojúewé',
'specialpages'      => 'Àwọn ojúewé pàtàkì',
'spheading'         => 'Àwọn ojúewé Pàtàkì fún gbogbo àwọn ẹnitínṣe',
'newpages'          => 'Àwọn ojúewé tuntun',
'newpages-username' => 'Orúkọ oníṣe:',

# Special:Log
'specialloguserlabel'  => 'Oníṣe:',
'speciallogtitlelabel' => 'Àkọlé:',

# Special:Allpages
'allarticles'       => 'Gbogbo ojúewé',
'allinnamespace'    => 'Gbogbo ojúewé ($1 namespace)',
'allnotinnamespace' => 'Gbogbo ojúewé (tí kòsí ní $1 namespace)',

# Watchlist
'watchlist'       => 'Ìmójútó mi',
'mywatchlist'     => 'Ìmójútó mi',
'watch'           => "M'ójútó",
'watchthispage'   => "M'ójútó ojúewé yi",
'unwatch'         => "Já'wọ́ ìmójútó",
'unwatchthispage' => "Já'wọ́ ìmójútó ojúewé yi",

# Namespace form on various pages
'blanknamespace' => '(Gbangba)',

# Contributions
'contributions' => 'Àwọn àfikún ẹnitínṣe',
'mycontris'     => 'Àwọn àfikún mi',

# What links here
'whatlinkshere'      => 'Ìjápọ̀ mọ́ ojúewé yí',
'whatlinkshere-page' => 'Ojúewé:',

# Namespace 8 related
'allmessagesname' => 'Orúkọ',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Ojúewé mi',
'tooltip-p-logo'      => 'Ojúewé Àkọ́kọ́',

# Attribution
'lastmodifiedatby' => 'Igba ti a se atunse si ojuewe yi gbeyin ni $2, $1 by $3.', # $1 date, $2 time, $3 user

);

==> mediawiki-1.13.1.tar.gz: mediawiki-1.13.1/languages/messages/MessagesYo.php <==
<?php
/** Yoruba (Yorùbá)
 *
 * @ingroup Language
 * @file
 *
 * @author Demmy
 */

$messages = array(
# User preference toggles
'tog-underline'            => 'Underline links:',
'tog-justify'              => "S'àlàyé gbólóhùn ọ̀rọ̀",
'tog-hideminor'            => "Bo àtúnse kékékèé mọ́'lẹ̀ nínú àtúnse tuntun",
'tog-rememberpassword'     => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi",
'tog-watchcreations'       => "S'àfikún ojúewé tí mo dá mọ́ ìmójútó mi",
'tog-watchdefault'         => "S'àfikún ojúewé tí mo s'àtúnse mọ́ ìmójútó mi",
'tog-watchmoves'           => "S'àfikún ojúewé tí mo kó kúrò mọ́ ìmójútó mi",
'tog-watchdeletion'        => "S'àfikún ojúewé tí mo parẹ́ mọ́ ìmójútó mi",
'tog-minordefault'         => "Se àmì sí gbogbo àtúnse gẹ́gẹ́ bi kékeré lát'ìbẹ̀rẹ̀.",
'tog-previewontop'         => "Se àyẹ̀wò kí ẹ tó s'àtúnṣe",
'tog-previewonfirst'       => "S'àfihàn àgbéwò fún àtúnse àkọ́kọ́",
'tog-nocache'              => "D'ènà fífi ojúewé pamọ́",
'tog-enotifwatchlistpages' => 'Fi e-mail ránsẹ́ sími tí ojúewé tí mò ún mójútó bá yípadà',
'tog-enotifusertalkpages'  => 'Fi e-mail ránsẹ́ sími tí ojúewé ẹnitínse mi bá yípadà',
'tog-enotifminoredits'     => 'Fi e-mail ránsẹ́ sími bákannà fún àtúnse kékékèé sí ojúewé',
'tog-shownumberswatching'  => "S'àfihàn iye àwọn ẹnitínse tí wọn ún mójútó",

'underline-always' => 'Nígbà gbogbo',

# Dates
'sunday'    => 'Ọjọ́àìkú',
'monday'    => 'Ọjọ́ajé',
'tuesday'   => 'Ọjọ́ìsẹ́gun',
'wednesday' => 'Ọjọ́rú',
'thursday'  => 'Ọjọ́bọ̀',
'friday'    => 'Ọjọ́ẹtì',
'saturday'  => 'Ọjọ́àbámẹ́ta',

'about'          => 'Nípa',
'cancel'         => "Fa'gilé",
'qbfind'         => 'Wá rí',
'qbedit'         => 'Àtúnṣe',
'qbpageoptions'  => 'Ojúewé yi',
'qbmyoptions'    => 'Àwọn ojúewé mi',
'qbspecialpages' => 'Àwọn ojúewé pàtàkì',
'moredotdotdot'  => 'Ẹ̀kúnrẹ́rẹ́...',
'mypage'         => 'Ojúewé mi',
'mytalk'         => 'Ọ̀rọ̀ mi',
'navigation'     => 'Atọ́ka',
'and'            => 'àti',

'errorpagetitle'   => 'Àsìse',
'tagline'          => "Lát'ọwọ́ {{SITENAME}}",
'help'             => 'Ìrànlọ́wọ́',
'search'           => 'Ṣe àwáàrí',
'searchbutton'     => 'Ṣe àwáàrí',
'go'               => 'Ó yá',
'searcharticle'    => 'Ó yá',
'edit'             => 'Àtúnṣe',
'create'           => "Ṣè'dá",
'editthispage'     => "S'àtúnṣe ojúewé yi",
'create-this-page' => "Ṣè'dá ojúewé yìí",
'delete'           => 'Paarẹ́',
'deletethispage'   => 'Pa ojúewé yi rẹ́',
'protect'          => 'Dábòbò',
'protectthispage'  => 'Dá àbò bo ojúewé yìí',
'newpage'          => 'Ojúewé tuntun',
'talkpage'         => 'Kábárawasọ̀rọ̀ nípa ojúewé yi',
'talkpagelinktext' => 'Kábárawasọ̀rọ̀',
'specialpage'      => 'Ojúewé Pàtàkì',
'talk'             => 'Ìfọ̀rọ̀wérọ̀',
'toolbox'          => 'Àpótí irinṣẹ',
'otherlanguages'   => 'Àwọn èdè míràn',
'lastmodifiedat'   => 'Ọjọ́ tí a ṣe àtunṣe ojúewé yi gbẹ̀yìn ni $2, $1.', # $1 date, $2 time
'viewcount'        => 'A ti wo ojúewé yi ni {{PLURAL:$1|ẹ̀kan péré|iye ìgbà $1}}.',
'jumptonavigation' => 'atọ́ka',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Nípa {{SITENAME}}',
'aboutpage'            => 'Project:Nípa',
'copyright'            => 'Gbogbo ohun inú ibí yi wà lábẹ́  $1.',
'copyrightpagename'    => '{{SITENAME}} ẹ̀tọ́àwòkọ',
'copyrightpage'        => '{{ns:project}}:Ẹ̀tọ́àwòko',
'currentevents'        => 'Ìròhìn nísinsìnyí',
'currentevents-url'    => 'Project:Ìròhìn nísinsìnyí',
'edithelp'             => "Ìrànlọ́wọ́ láti s'àtúnṣe",
'edithelppage'         => 'Help:Àtúnṣe',
'mainpage'             => 'Ojúewé Àkọ́kọ́',
'mainpage-description' => 'Ojúewé Àkọ́kọ́',
'portal'               => 'Èbúté àwùjọ',
'portal-url'           => 'Project:Èbúté Àwùjọ',

'badaccess-group0' => "A kò gbàyín l'áyè l'áti ṣe ohun tí ẹ bèrè fún.",

'youhavenewmessages'      => 'Ẹ ní $1 ($2).',
'newmessageslink'         => 'ìfọ̀rọ̀ránsẹ́ tuntun',
'youhavenewmessagesmulti' => 'Ẹ ní ìfọ̀rọ̀ránsẹ́ tuntun ni $1',
'editsection'             => "s'àtúnṣe",
'editold'                 => "s'àtúnṣe",
'showtoc'                 => 'fihàn',
'hidetoc'                 => 'bòmọ́lẹ̀',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Àyọkà',
'nstab-user'      => 'Ojúewé oníṣe',
'nstab-media'     => 'Ojúewé amóhùnmáwòrán',
'nstab-special'   => 'Pàtàkì',
'nstab-mediawiki' => 'Ìfọ̀rọ̀ránsẹ',
'nstab-category'  => 'Ẹ̀ka',

# General errors
'viewsource'        => 'Àfihàn ọ̀rọ̀àmì',
'protectedpagetext' => 'A ti se àtìpa ojúewé yi. Ẹ kò le se àtúnṣe.',
'viewsourcetext'    => 'Ẹ lè wo ati ẹ lè se àwòkọ ọ̀rọ̀àmì ojúewé yi:',
'titleprotected'    => "This title has been protected from creation by [[User:$1|$1]]. The reason given is ''$2''.",

# Login and logout pages
'logouttitle'             => 'Ibọsóde oníṣe',
'welcomecreation'         => "== Ẹ kú àbọ̀, $1! ==

A ti fi orúkọ yín s'ílẹ̀. Ẹ mọ́ gbàgbé l'áti s'àtúnṣe àwọn ìfẹ́ràn {{SITENAME}} yín.",
'loginpagetitle'          => 'Ìwọlé oníṣe',
'yourname'                => 'Orúkọ oníṣe (username):',
'yourpassword'            => 'Ọ̀rọ̀ìpamọ́:',
'yourpasswordagain'       => 'Tẹkíkọ ọ̀rọ̀ìpamọ́ lẹ́ẹ̀kansí:',
'remembermypassword'      => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi (cookies)",
'loginproblem'            => '<b>Ẹ ní ìṣòro láti wọlé.</b><br />Ẹ gbìyànjú lẹ́kan sí!',
'login'                   => 'Ìwọlé',
'nav-login-createaccount' => 'Ìwọlé / Ìforúkọ sílẹ̀',
'userlogin'               => 'Ìwọlé / ìforúkọ sílẹ̀',
'logout'                  => 'Ìbọ́sóde',
'userlogout'              => 'Ìbọ́sóde',
'notloggedin'             => "Ẹ kò tí w'ọlé",
'nologinlink'             => 'Ẹ fi orúkọ sílẹ̀',
'createaccount'           => 'Ẹ fi orúkọ sílẹ̀',
'gotaccountlink'          => "Ẹ w'ọlé",
'createaccountmail'       => 'pẹ̀lú e-mail',
'badretype'               => 'Àwọn ọ̀rọ̀ìpamọ́ tí ẹ kọ kò jọ ra wọn.',
'username'                => 'Orúkọ oníṣe:',
'uid'                     => 'Nọmba ìdámọ̀ fún ẹnitínṣe:',
'yourlanguage'            => 'Èdè:',
'accountcreated'          => 'Ẹ ti fi orúkọ sílẹ̀',
'accountcreatedtext'      => 'A ti fi orúkọ ẹnitínṣe sílẹ̀ fún $1',
'createaccount-title'     => 'Ìforúkọ sílẹ̀ fún {{SITENAME}}',
'loginlanguagelabel'      => 'Èdè: $1',

# Edit pages
'minoredit'        => 'Àtúnṣe kékeré nìyí',
'watchthis'        => "M'ójútó ojúewé yìí",
'savearticle'      => 'Ẹ fi pamọ́',
'preview'          => 'Àyẹ̀wò',
'showpreview'      => 'Àyẹ̀wò',
'showdiff'         => 'Àfihàn àwọn àyípadà',
'anoneditwarning'  => "'''Ìkìlọ̀:''' Ẹ ò tíì wọlé.
Á ṣe àkọsílẹ̀ ojúọ̀nà IP yín ninu ìwé àtúnṣe ojúewé yìí.",
'loginreqtitle'    => "Ẹ gbọ́dọ̀ kọ́kọ́ w'ọlé ná",
'newarticle'       => '(Tuntun)',
'newarticletext'   => "Ẹ ti tẹ̀lé ìjápọ̀ mọ́ ojúewé tí kò sí.
Láti dá ojúewé yí ẹ bẹ̀rẹ̀ síní tẹ́kọ sí inú àpótí ìsàlẹ̀ yí (ẹ wo [[{{MediaWiki:Helppage}}|ojúewé ìrànlọ́wọ́ ]] fun ẹ̀kúnrẹ́rẹ́ ).
T'óbá sepé àsìse ló gbé yin dé bi, ẹ kọn bọ́tìnì ìpadàsẹ́yìn.",
'note'             => '<strong>Àkíyèsí:</strong>',
'copyrightwarning' => 'Ẹ jọ̀wọ́ ẹ kíyèsi wípé gbogbo àwọn àfikún sí {{SITENAME}} jẹ́ bẹ̀ lábẹ́  $2 (Ẹ wo $1 fún ẹkunrẹrẹ ).
If you do not want your writing to be edited mercilessly and redistributed at will, then do not submit it here.<br />
You are also promising us that you wrote this yourself, or copied it from a public domain or similar free resource.
<strong>Ẹ mọ́ fi iṣẹ́ ẹlòmíràn sílẹ̀ láì gbàṣẹ!</strong>',

# Revision deletion
'rev-delundel' => 'fihàn/fipamọ́',

# Search results
'searchresults' => 'Àwọn èsì àwáàrí',
'powersearch'   => 'Ṣe àwáàrí',

# Preferences page
'preferences'      => 'Àwọn ìfẹ́ràn',
'mypreferences'    => 'Àwọn ìfẹ́ràn mi',
'prefs-edits'      => 'Iye àwọn àtúnṣe:',
'prefsnologintext' => 'Ẹ gbọ́dọ̀ [[Special:UserLogin|wọlé]] láti to àwọn ìfẹ́ràn oníṣe.',
'prefs-personal'   => 'Ọ̀rọ̀ nípa oníṣe',
'savedprefs'       => 'Àwọn ìfẹ́ràn yín ti wà nípamọ́.',

# Recent changes
'recentchanges' => 'Àwọn àtúnṣe tuntun',

# Special:ImageList
'imagelist_name' => 'Orúkọ',
'imagelist_user' => 'Oníṣe',

# Image description page
'filehist-user' => 'Oníṣe',
'linkstoimage'  => '{{PLURAL:$1|Ojúewé yí|$1 Àwọn ojúewé yí}} jápọ̀ mọ́ àpò yí:',

# File deletion
'filedelete'        => 'Paarẹ́ $1',
'filedelete-submit' => 'Paarẹ́',

# Miscellaneous special pages
'newpages'          => 'Àwọn ojúewé tuntun',
'newpages-username' => 'Orúkọ oníṣe:',

# Special:Log
'specialloguserlabel'  => 'Oníṣe:',
'speciallogtitlelabel' => 'Àkọlé:',

# Special:AllPages
'allpages'          => 'Gbogbo ojúewé',
'allarticles'       => 'Gbogbo ojúewé',
'allinnamespace'    => 'Gbogbo ojúewé ($1 namespace)',
'allnotinnamespace' => 'Gbogbo ojúewé (tí kòsí ní $1 namespace)',

# Watchlist
'watchlist'       => 'Ìmójútó mi',
'mywatchlist'     => 'Ìmójútó mi',
'watch'           => "M'ójútó",
'watchthispage'   => "M'ójútó ojúewé yi",
'unwatch'         => "Já'wọ́ ìmójútó",
'unwatchthispage' => "Já'wọ́ ìmójútó ojúewé yi",

# Namespace form on various pages
'blanknamespace' => '(Gbangba)',

# Contributions
'contributions' => 'Àwọn àfikún ẹnitínṣe',
'mycontris'     => 'Àwọn àfikún mi',

# What links here
'whatlinkshere'      => 'Ìjápọ̀ mọ́ ojúewé yí',
'whatlinkshere-page' => 'Ojúewé:',

# Namespace 8 related
'allmessagesname' => 'Orúkọ',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Ojúewé mi',
'tooltip-p-logo'      => 'Ojúewé Àkọ́kọ́',

# Attribution
'lastmodifiedatby' => 'Igba ti a se atunse si ojuewe yi gbeyin ni $2, $1 by $3.', # $1 date, $2 time, $3 user

# Special:SpecialPages
'specialpages' => 'Àwọn ojúewé pàtàkì',

);
